Package: SurfR
Type: Package
Title: Surface Protein Prediction and Identification
Version: 1.8.0
Authors@R: c(person("Aurora", "Maurizio", email="auroramaurizio1@gmail.com", role = c("aut","cre"), comment = c(ORCID = "0000-0002-7194-4637")),
           person("Anna Sofia", "Tascini", email="volpesofi@gmail.com", role = c("aut", "ctb"), comment = c(ORCID = "0000-0001-5731-5490")))
Description: Identify Surface Protein coding genes from a list of candidates.
             Systematically download data from GEO and TCGA or use your own data. 
             Perform DGE on bulk RNAseq data. 
             Perform Meta-analysis. Descriptive enrichment analysis and plots.
License: GPL-3 + file LICENSE
Encoding: UTF-8
LazyData: false
BugReports: https://github.com/auroramaurizio/SurfR/issues
URL: https://github.com/auroramaurizio/SurfR
biocViews: Software, Sequencing, RNASeq, GeneExpression, Transcription,
        DifferentialExpression, PrincipalComponent, GeneSetEnrichment,
        Pathways, BatchEffect, FunctionalGenomics, Visualization,
        DataImport, FunctionalPrediction, GenePrediction, GO
VignetteBuilder: knitr
RoxygenNote: 7.2.3
Imports: httr, BiocFileCache, SPsimSeq, DESeq2, edgeR, openxlsx,
        stringr, rhdf5, ggplot2, ggrepel, stats, magrittr, assertr,
        tidyr, dplyr, TCGAbiolinks, biomaRt, metaRNASeq, scales, venn,
        gridExtra, SummarizedExperiment, knitr, rjson, grDevices,
        graphics, curl, utils
Depends: R (>= 4.4.0)
Suggests: BiocStyle, testthat (>= 3.0.0)
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/SurfR
git_branch: RELEASE_3_23
git_last_commit: fba3adc
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:41:34 UTC; biocbuild
Author: Aurora Maurizio [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7194-4637>),
  Anna Sofia Tascini [aut, ctb] (ORCID:
    <https://orcid.org/0000-0001-5731-5490>)
Maintainer: Aurora Maurizio <auroramaurizio1@gmail.com>
Built: R 4.6.0; ; 2026-04-29 05:03:07 UTC; unix
