# Generated by roxygen2: do not edit by hand

export(Annotate_SPID)
export(DGE)
export(DownloadArchS4)
export(Enrichment)
export(Enrichment_barplot)
export(GEOmetadata)
export(Gene2SProtein)
export(SVenn)
export(Splot)
export(TCGA_download)
export(combine_fisher_invnorm)
export(enrichr)
export(enrichr_download)
export(listEnrichrDbs)
export(metaRNAseq)
export(plotPCA)
export(setEnrichrSite)
import(BiocFileCache)
import(SPsimSeq)
import(biomaRt)
import(knitr)
importFrom(DESeq2,DESeq)
importFrom(DESeq2,DESeqDataSetFromMatrix)
importFrom(DESeq2,counts)
importFrom(DESeq2,results)
importFrom(SummarizedExperiment,assay)
importFrom(TCGAbiolinks,GDCdownload)
importFrom(TCGAbiolinks,GDCprepare)
importFrom(TCGAbiolinks,GDCquery)
importFrom(assertr,col_concat)
importFrom(dplyr,group_by)
importFrom(dplyr,relocate)
importFrom(dplyr,summarise)
importFrom(dplyr,ungroup)
importFrom(edgeR,cpm)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_fixed)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggsave)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_gradient)
importFrom(ggplot2,scale_shape_manual)
importFrom(ggplot2,scale_x_discrete)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,unit)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(ggrepel,geom_label_repel)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(graphics,hist)
importFrom(gridExtra,marrangeGrob)
importFrom(httr,GET)
importFrom(httr,POST)
importFrom(httr,content)
importFrom(httr,http_status)
importFrom(httr,status_code)
importFrom(httr,use_proxy)
importFrom(magrittr,"%>%")
importFrom(metaRNASeq,fishercomb)
importFrom(metaRNASeq,invnorm)
importFrom(openxlsx,read.xlsx)
importFrom(openxlsx,write.xlsx)
importFrom(rhdf5,H5close)
importFrom(rhdf5,h5read)
importFrom(rjson,fromJSON)
importFrom(scales,hue_pal)
importFrom(stats,as.formula)
importFrom(stats,prcomp)
importFrom(stringr,str_remove_all)
importFrom(stringr,str_replace)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_split)
importFrom(stringr,str_sub)
importFrom(tidyr,separate_rows)
importFrom(utils,head)
importFrom(utils,read.table)
importFrom(utils,write.table)
importFrom(venn,venn)
