% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Annotate_SPID.R
\name{enrichr_connect}
\alias{enrichr_connect}
\title{Connect to the enrichr web application  - function from hypeR}
\usage{
enrichr_connect(endpoint, db = c("Enrichr"))
}
\arguments{
\item{endpoint}{The url endpoint to connect to}

\item{db}{A species}
}
\value{
A web response
}
\description{
Connect to the enrichr web application  - function from hypeR
}
\keyword{internal}
