% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Annotate_SPID.R
\name{enrichr_urls}
\alias{enrichr_urls}
\title{Get url base for species-specific enrichr libraries  - function from hypeR}
\usage{
enrichr_urls(db = c("Enrichr"))
}
\arguments{
\item{db}{A species}
}
\value{
A url
}
\description{
Get url base for species-specific enrichr libraries  - function from hypeR
}
\keyword{internal}
